==> qumulo_api-1.2.12.1.tar.gz: qumulo_api-1.2.12.1/qumulo/commands/cluster.py <==
# Copyright (c) 2013 Qumulo, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may not
# use this file except in compliance with the License. You may obtain a copy of
# the License at http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations under
# the License.

import qumulo.lib.opts
import qumulo.lib.util
import qumulo.rest.cluster as cluster

class ListNodesCommand(qumulo.lib.opts.Subcommand):
    NAME = "nodes_list"
    DESCRIPTION = "List nodes"

    @staticmethod
    def options(parser):
        parser.add_argument("--node", help="Node ID")

    @staticmethod
    def main(conninfo, credentials, _args):
        if _args.node is not None:
            print cluster.list_node(conninfo, credentials, _args.node)
        else:
            print cluster.list_nodes(conninfo, credentials)

class GetClusterConfCommand(qumulo.lib.opts.Subcommand):
    NAME = "cluster_conf"
    DESCRIPTION = "Get the cluster config"

    @staticmethod
    def main(conninfo, credentials, _args):
        print cluster.get_cluster_conf(conninfo, credentials)

class SetClusterConfCommand(qumulo.lib.opts.Subcommand):
    NAME = "set_cluster_conf"
    DESCRIPTION = "Set the cluster config"

    @staticmethod
    def options(parser):
        parser.add_argument("--cluster-name", help="Cluster Name",
                            required=True)

    @staticmethod
    def main(conninfo, credentials, _args):
        print cluster.put_cluster_conf(conninfo, credentials,
            _args.cluster_name)

class GetClusterSlotStatusCommand(qumulo.lib.opts.Subcommand):
    NAME = "cluster_slots"
    DESCRIPTION = "Get the cluster disk slots status"

    @staticmethod
    def options(parser):
        parser.add_argument("--slot", help="Slot ID")

    @staticmethod
    def main(conninfo, credentials, args):
        if args.slot is not None:
            print cluster.get_cluster_slot_status(
                conninfo, credentials, args.slot)
        else:
            print cluster.get_cluster_slots_status(
                conninfo, credentials)

class GetRestriperStatusCommand(qumulo.lib.opts.Subcommand):
    NAME = "restriper_status"
    DESCRIPTION = "Get restriper and data protection status"

    @staticmethod
    def main(conninfo, credentials, _args):
        print cluster.get_restriper_status(conninfo, credentials)

==> qumulo_api-1.2.19.tar.gz: qumulo_api-1.2.19/qumulo/commands/cluster.py <==
# Copyright (c) 2013 Qumulo, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may not
# use this file except in compliance with the License. You may obtain a copy of
# the License at http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations under
# the License.

import qumulo.lib.opts
import qumulo.lib.util
import qumulo.rest.cluster as cluster

class ListNodesCommand(qumulo.lib.opts.Subcommand):
    NAME = "nodes_list"
    DESCRIPTION = "List nodes"

    @staticmethod
    def options(parser):
        parser.add_argument("--node", help="Node ID")

    @staticmethod
    def main(conninfo, credentials, _args):
        if _args.node is not None:
            print cluster.list_node(conninfo, credentials, _args.node)
        else:
            print cluster.list_nodes(conninfo, credentials)

class GetClusterConfCommand(qumulo.lib.opts.Subcommand):
    NAME = "cluster_conf"
    DESCRIPTION = "Get the cluster config"

    @staticmethod
    def main(conninfo, credentials, _args):
        print cluster.get_cluster_conf(conninfo, credentials)

class SetClusterConfCommand(qumulo.lib.opts.Subcommand):
    NAME = "set_cluster_conf"
    DESCRIPTION = "Set the cluster config"

    @staticmethod
    def options(parser):
        parser.add_argument("--cluster-name", help="Cluster Name",
                            required=True)

    @staticmethod
    def main(conninfo, credentials, _args):
        print cluster.put_cluster_conf(conninfo, credentials,
            _args.cluster_name)

class GetClusterSlotStatusCommand(qumulo.lib.opts.Subcommand):
    NAME = "cluster_slots"
    DESCRIPTION = "Get the cluster disk slots status"

    @staticmethod
    def options(parser):
        parser.add_argument("--slot", help="Slot ID")

    @staticmethod
    def main(conninfo, credentials, args):
        if args.slot is not None:
            print cluster.get_cluster_slot_status(
                conninfo, credentials, args.slot)
        else:
            print cluster.get_cluster_slots_status(
                conninfo, credentials)

class GetRestriperStatusCommand(qumulo.lib.opts.Subcommand):
    NAME = "restriper_status"
    DESCRIPTION = "Get restriper status"

    @staticmethod
    def main(conninfo, credentials, _args):
        print cluster.get_restriper_status(conninfo, credentials)

class GetProtectionStatusCommand(qumulo.lib.opts.Subcommand):
    NAME = "protection_status_get"
    DESCRIPTION = "Get cluster protection status"

    @staticmethod
    def main(conninfo, credentials, _args):
        print cluster.get_protection_status(conninfo, credentials)
